export const defaultPerf = (typeof performance === 'object' &&
    performance &&
    typeof performance.now === 'function') ?
    /* c8 ignore start - this gets covered, but c8 gets confused */
    performance
    : /* c8 ignore stop */ Date;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/93cfdd489c3b228840d0f86ec77c3636277c93ea/node_modules/@xterm/addon-ligatures/node_modules/lru-cache/dist/esm/browser/perf.js.map