/*
 * Application Insights JavaScript SDK - Core, 2.8.15
 * Copyright (c) Microsoft and contributors. All rights reserved.
 */


export {};
//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/93cfdd489c3b228840d0f86ec77c3636277c93ea/node_modules/@microsoft/applicationinsights-core-js/dist-esm/JavaScriptSDK.Enums/TelemetryUpdateReason.js.map