// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { createDefaultHttpClient } from "@azure/core-rest-pipeline";
let cachedHttpClient;
export function getCachedDefaultHttpClient() {
    if (!cachedHttpClient) {
        cachedHttpClient = createDefaultHttpClient();
    }
    return cachedHttpClient;
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/93cfdd489c3b228840d0f86ec77c3636277c93ea/node_modules/@azure/core-client/dist/esm/httpClientCache.js.map