// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export {};//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/93cfdd489c3b228840d0f86ec77c3636277c93ea/node_modules/@azure/identity/dist/esm/msal/browserFlows/msalBrowserOptions.js.map