"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tracing = exports.metrics = void 0;
const dummy = { hasSubscribers: false };
exports.metrics = dummy;
exports.tracing = dummy;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/93cfdd489c3b228840d0f86ec77c3636277c93ea/node_modules/@xterm/addon-ligatures/node_modules/lru-cache/dist/commonjs/browser/diagnostics-channel-browser.js.map